@@ -37,10 +37,10 @@ class Route(str, Enum):
     export = "export"
     edits = "edits"
     export_edits = "edits/export"
-    upload_dataset = "upload_dataset"
     ampli = "ampli"
     notify = "notify/email"
     token = "get-token"
+    upload_file = "upload_file"
 
     @staticmethod
     def content_path(
